
#ifndef VTKRENDERINGFFMPEGOPENGL2_EXPORT_H
#define VTKRENDERINGFFMPEGOPENGL2_EXPORT_H

#ifdef VTKRENDERINGFFMPEGOPENGL2_STATIC_DEFINE
#  define VTKRENDERINGFFMPEGOPENGL2_EXPORT
#  define VTKRENDERINGFFMPEGOPENGL2_NO_EXPORT
#else
#  ifndef VTKRENDERINGFFMPEGOPENGL2_EXPORT
#    ifdef RenderingFFMPEGOpenGL2_EXPORTS
        /* We are building this library */
#      define VTKRENDERINGFFMPEGOPENGL2_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKRENDERINGFFMPEGOPENGL2_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKRENDERINGFFMPEGOPENGL2_NO_EXPORT
#    define VTKRENDERINGFFMPEGOPENGL2_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKRENDERINGFFMPEGOPENGL2_DEPRECATED
#  define VTKRENDERINGFFMPEGOPENGL2_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKRENDERINGFFMPEGOPENGL2_DEPRECATED_EXPORT
#  define VTKRENDERINGFFMPEGOPENGL2_DEPRECATED_EXPORT VTKRENDERINGFFMPEGOPENGL2_EXPORT VTKRENDERINGFFMPEGOPENGL2_DEPRECATED
#endif

#ifndef VTKRENDERINGFFMPEGOPENGL2_DEPRECATED_NO_EXPORT
#  define VTKRENDERINGFFMPEGOPENGL2_DEPRECATED_NO_EXPORT VTKRENDERINGFFMPEGOPENGL2_NO_EXPORT VTKRENDERINGFFMPEGOPENGL2_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKRENDERINGFFMPEGOPENGL2_NO_DEPRECATED
#    define VTKRENDERINGFFMPEGOPENGL2_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkRenderingFFMPEGOpenGL2Module.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKRENDERINGFFMPEGOPENGL2_EXPORT_H */
